@@ -89,7 +89,7 @@ func (f *FishBuff) CurrentSuggestion() (string, bool) {
 }
 
 // AutoSuggests returns true if model implements auto suggestions.
-func (f *FishBuff) AutoSuggests() bool {
+func (*FishBuff) AutoSuggests() bool {
 	return true
 }
 
@@ -107,7 +107,7 @@ func (f *FishBuff) SetSuggestionFn(fn SuggestionFunc) {
 }
 
 // Notify publish suggestions to all listeners.
-func (f *FishBuff) Notify(delete bool) {
+func (f *FishBuff) Notify(_ bool) {
 	if f.suggestionFn == nil {
 		return
 	}
@@ -136,5 +136,4 @@ func (f *FishBuff) fireSuggestionChanged(ss []string) {
 		suggest = ss[f.suggestionIndex]
 	}
 	f.SetText(f.GetText(), suggest)
-
 }
